summaryrefslogtreecommitdiff
path: root/sql/sql_time.cc
diff options
context:
space:
mode:
authorAlexander Barkov <bar@mariadb.com>2018-11-14 16:00:38 +0400
committerAlexander Barkov <bar@mariadb.com>2018-11-14 16:00:38 +0400
commitb9a9055793ab8b9a50200e2f55602463627dedd3 (patch)
treebb245b2e03aa973439f7c50f69019b8622bf22af /sql/sql_time.cc
parent62bcd74712680fa07c9ed8c42c384c8825c4f9af (diff)
downloadmariadb-git-b9a9055793ab8b9a50200e2f55602463627dedd3.tar.gz
MDEV-17712 Remove C_TIME_FUZZY_DATES, C_TIME_DATETIME_ONLY, C_TIME_TIME_ONLY
Diffstat (limited to 'sql/sql_time.cc')
-rw-r--r--sql/sql_time.cc24
1 files changed, 13 insertions, 11 deletions
diff --git a/sql/sql_time.cc b/sql/sql_time.cc
index 9562394f11e..ff02bfa0ae4 100644
--- a/sql/sql_time.cc
+++ b/sql/sql_time.cc
@@ -371,13 +371,14 @@ public:
};
-/* Character set-aware version of str_to_time() */
-bool Temporal::str_to_time(MYSQL_TIME_STATUS *status,
- const char *str, size_t length, CHARSET_INFO *cs,
- date_mode_t fuzzydate)
+/* Character set-aware version of str_to_datetime_or_date_or_time() */
+bool Temporal::str_to_datetime_or_date_or_time(MYSQL_TIME_STATUS *status,
+ const char *str, size_t length,
+ CHARSET_INFO *cs,
+ date_mode_t fuzzydate)
{
TemporalAsciiBuffer tmp(str, length, cs);
- bool rc= ::str_to_time(tmp.str, tmp.length, this,
+ bool rc= ::str_to_datetime_or_date_or_time(tmp.str, tmp.length, this,
ulonglong(fuzzydate & TIME_MODE_FOR_XXX_TO_DATE),
status);
DBUG_ASSERT(status->warnings || !rc);
@@ -385,13 +386,14 @@ bool Temporal::str_to_time(MYSQL_TIME_STATUS *status,
}
-/* Character set-aware version of str_to_datetime() */
-bool Temporal::str_to_datetime(MYSQL_TIME_STATUS *status,
- const char *str, size_t length, CHARSET_INFO *cs,
- date_mode_t flags)
+/* Character set-aware version of str_to_datetime_or_date() */
+bool Temporal::str_to_datetime_or_date(MYSQL_TIME_STATUS *status,
+ const char *str, size_t length,
+ CHARSET_INFO *cs,
+ date_mode_t flags)
{
TemporalAsciiBuffer tmp(str, length, cs);
- bool rc= ::str_to_datetime(tmp.str, tmp.length, this,
+ bool rc= ::str_to_datetime_or_date(tmp.str, tmp.length, this,
ulonglong(flags & TIME_MODE_FOR_XXX_TO_DATE),
status);
DBUG_ASSERT(status->warnings || !rc);
@@ -416,7 +418,7 @@ bool Interval_DDhhmmssff::str_to_DDhhmmssff(MYSQL_TIME_STATUS *status,
if string was truncated during conversion.
NOTE
- See description of str_to_datetime() for more information.
+ See description of str_to_datetime_xxx() for more information.
*/
bool